Module config_analysis

Module config_analysis 

Functions

is_supported_config_path
Return whether a path is a supported framework configuration source.
parse_config_document
Parse a recognized framework configuration file without executing it.