pub struct CssVariableManager { /* private fields */ }Expand description
Manages CSS variables across the workspace
Implementations
Sourceimpl CssVariableManager
impl CssVariableManager
pub fn new(config: Config) -> Self
Sourcepub async fn add_variable(&self, variable: CssVariable) -> Result<(), String>
pub async fn add_variable(&self, variable: CssVariable) -> Result<(), String>
Add a variable definition
Sourcepub async fn add_usage(&self, usage: CssVariableUsage)
pub async fn add_usage(&self, usage: CssVariableUsage)
Add a variable usage
Sourcepub async fn add_literal_color(&self, occurrence: LiteralColorOccurrence)
pub async fn add_literal_color(&self, occurrence: LiteralColorOccurrence)
Add a literal color occurrence
Sourcepub async fn get_variables(&self, name: &str) -> Vec<CssVariable>
pub async fn get_variables(&self, name: &str) -> Vec<CssVariable>
Get all definitions of a variable
Sourcepub async fn get_usages(&self, name: &str) -> Vec<CssVariableUsage>
pub async fn get_usages(&self, name: &str) -> Vec<CssVariableUsage>
Get all usages of a variable
Sourcepub async fn resolve_variable_color(&self, name: &str) -> Option<Color>
pub async fn resolve_variable_color(&self, name: &str) -> Option<Color>
Resolve a variable name to a color using cascade ordering and var() chains.
Sourcepub async fn resolve_variable_color_key(
&self,
name: &str,
) -> Option<NormalizedColorKey>
pub async fn resolve_variable_color_key( &self, name: &str, ) -> Option<NormalizedColorKey>
Resolve a variable name to a normalized color key using cascade ordering and var() chains.
Sourcepub async fn get_all_variables(&self) -> Vec<CssVariable>
pub async fn get_all_variables(&self) -> Vec<CssVariable>
Get all variables (for completion)
Sourcepub async fn get_references(
&self,
name: &str,
) -> (Vec<CssVariable>, Vec<CssVariableUsage>)
pub async fn get_references( &self, name: &str, ) -> (Vec<CssVariable>, Vec<CssVariableUsage>)
Get all references (definitions + usages) for a variable
Sourcepub async fn get_document_literal_colors(
&self,
uri: &Uri,
) -> Vec<LiteralColorOccurrence>
pub async fn get_document_literal_colors( &self, uri: &Uri, ) -> Vec<LiteralColorOccurrence>
Get literal color occurrences in a specific document.
Sourcepub async fn get_literal_colors_at_position(
&self,
uri: &Uri,
position: Position,
) -> Vec<LiteralColorOccurrence>
pub async fn get_literal_colors_at_position( &self, uri: &Uri, position: Position, ) -> Vec<LiteralColorOccurrence>
Get literal color occurrences at a specific position (O(1) line lookup + O(k) scan).
Sourcepub async fn get_variables_by_color_key(
&self,
key: &NormalizedColorKey,
) -> Vec<CssVariable>
pub async fn get_variables_by_color_key( &self, key: &NormalizedColorKey, ) -> Vec<CssVariable>
Get all variables whose resolved color exactly matches the normalized color key.
Sourcepub async fn get_document_resolved_color_keys(
&self,
uri: &Uri,
) -> HashSet<NormalizedColorKey>
pub async fn get_document_resolved_color_keys( &self, uri: &Uri, ) -> HashSet<NormalizedColorKey>
Get the set of resolved variable colors currently defined in a specific document.
Sourcepub async fn remove_document(&self, uri: &Uri)
pub async fn remove_document(&self, uri: &Uri)
Remove all data for a document
Sourcepub async fn get_document_variables(&self, uri: &Uri) -> Vec<CssVariable>
pub async fn get_document_variables(&self, uri: &Uri) -> Vec<CssVariable>
Get all variables defined in a specific document
Sourcepub async fn get_document_variable_names(&self, uri: &Uri) -> HashSet<String>
pub async fn get_document_variable_names(&self, uri: &Uri) -> HashSet<String>
Get the set of variable names defined in a specific document
Sourcepub async fn get_document_usages(&self, uri: &Uri) -> Vec<CssVariableUsage>
pub async fn get_document_usages(&self, uri: &Uri) -> Vec<CssVariableUsage>
Get all variable usages in a specific document
Sourcepub async fn set_dom_tree(&self, uri: Uri, dom_tree: DomTree)
pub async fn set_dom_tree(&self, uri: Uri, dom_tree: DomTree)
Set DOM tree for a document
Sourcepub async fn get_dom_tree(&self, uri: &Uri) -> Option<DomTree>
pub async fn get_dom_tree(&self, uri: &Uri) -> Option<DomTree>
Get DOM tree for a document
Sourcepub async fn get_config(&self) -> Config
pub async fn get_config(&self) -> Config
Get current configuration
Sourcepub async fn set_config(&self, config: Config)
pub async fn set_config(&self, config: Config)
Replace the current configuration.
Sourcepub async fn rebuild_color_index(&self)
pub async fn rebuild_color_index(&self)
Rebuild the normalized-color -> variable-name lookup from current workspace state.